import findConfig from 'find-config'

import {
  fetchPolicies,
  fetchNotificationChannels,
  createPolicy,
  updatePolicy,
  createNotificationChannel,
  associateChannelWithPolicy,
  removePolicyConditions,
  createNRQLCondition,
  removeStaleNotificationAssociation
} from './api'
import {
  log,
  err,
  accessMap,
  findPolicy,
  findNotificationChannel
} from './helpers'

const config = JSON.parse(findConfig.read('.newrelicalerts'))

if (!config) {
  err('Could not find .newrelicalerts config file')
}

if (!process.env.NEWRELIC_API_KEY) {
  err('No available NEWRELIC_API_KEY env var')
}

;(async function() {
  const policies = await fetchPolicies()
  const notificationChannels = await fetchNotificationChannels()

  const getPolicyId = async (policies, name, preference) => {
    const existingPolicy = findPolicy(policies, name)

    return existingPolicy
      ? updatePolicy(existingPolicy.id, name, preference)
      : createPolicy(name, preference)
  }

  const getNotificationId = async (name, notification) => {
    const existingNotificationChannel = findNotificationChannel(
      notificationChannels,
      notification.type,
      notification.channel
    )

    return existingNotificationChannel
      ? existingNotificationChannel.id
      : createNotificationChannel(
          name,
          notification.url,
          notification.type,
          notification.channel
        )
  }

  config.policies.forEach(
    async ({ name, notification = {}, condition = {} }) => {
      if (!accessMap[notification.type]) {
        err('Invalid notification type')
      }

      if (!accessMap[notification.type].isValid(notification)) {
        err(`Policy "${name}" requires a valid notification object`)
      }

      log(`Creating policy "${name}"`)

      try {
        const policyId = await getPolicyId(policies, name)
        const notificationId = await getNotificationId(name, notification)

        await removePolicyConditions(policyId)
        await removeStaleNotificationAssociation(policyId, notificationChannels)

        associateChannelWithPolicy(policyId, notificationId)
        createNRQLCondition(policyId, condition)
      } catch (error) {
        throw error
      }
    }
  )
})()
